/* Compatibility layer for using upstream CLooG versions with
   CLooG legacy code.
   Copyright (C) 2010, 2011 Free Software Foundation, Inc.
   Contributed by Andreas Simbuerger <simbuerg@fim.uni-passau.de>.

This file is part of GCC.

GCC is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

GCC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with GCC; see the file COPYING3.  If not see
<http://www.gnu.org/licenses/>.  */

#ifndef GRAPHITE_CLOOG_COMPAT_H
#define GRAPHITE_CLOOG_COMPAT_H

/* Restore compatibility to CLooG Legacy.  */
#ifdef CLOOG_ORG
typedef const struct clast_expr *clast_name_p;
#else
typedef const char *clast_name_p;
#endif

#ifdef CLOOG_ORG
#define cloog_initialize()
#define cloog_finalize()
#endif

#ifndef CLOOG_ORG

/* CloogOptions compatibility.  */
#define build_cloog_prog(SCOP, PROG, OPT)\
  build_cloog_prog (SCOP, PROG)
#define cloog_program_extract_scalars(PROG, SCATT, OPT)\
  cloog_program_extract_scalars (PROG, SCATT)
#define cloog_program_scatter(PROG, SCATT, OPT)\
  cloog_program_scatter (PROG, SCATT)

/* CLAST compatibility.  */
#define clast_expr_term expr_term
#define clast_expr_red expr_red
#define clast_expr_bin expr_bin
#define clast_pprint pprint

/* CloogState compatibility.  */
#define CloogState void
#define cloog_state_malloc() NULL
#define cloog_state_free(STATE)
#define cloog_loop_malloc(STATE) cloog_loop_malloc ()
#define cloog_options_malloc(STATE) cloog_options_malloc ()
#define cloog_statement_alloc(STATE, INDEX) cloog_statement_alloc (INDEX)
#define new_Cloog_Domain_from_ppl_Pointset_Powerset(PSPS, NB, STATE)\
  new_Cloog_Domain_from_ppl_Pointset_Powerset (PSPS)
#define new_Cloog_Domain_from_ppl_Polyhedron(POLY, NB, STATE)\
  new_Cloog_Domain_from_ppl_Polyhedron (POLY)
#define cloog_domain_from_cloog_matrix(STATE, MAT, NB)\
  cloog_domain_matrix2domain (MAT)

/* CloogScatteringList compatibility.  */
#define CloogScatteringList CloogDomainList
#define CloogScattering CloogDomain
#define cloog_set_next_scattering cloog_set_next_domain
#define cloog_set_scattering cloog_set_domain
#define cloog_scattering cloog_domain
#define cloog_next_scattering cloog_next_domain
#define cloog_scattering_free cloog_domain_free
#define cloog_program_dump_cloog(DUMPFILE, PROGRAM, SCATTERINGLIST)\
  cloog_program_dump_cloog (DUMPFILE, PROGRAM)

#endif

/* Adapt CLooG accessors from CLooG legacy to
   newer CLooG versions.  */

#ifdef CLOOG_ORG

static inline void *
cloog_statement_usr (CloogStatement *cs)
{
  return cs->usr;
}

static inline CloogScattering *
cloog_scattering (CloogScatteringList *sl)
{
  return sl->scatt;
}

static inline void
cloog_set_scattering (CloogScatteringList *sl, CloogScattering *scatt)
{
  sl->scatt = scatt;
}

static inline CloogScatteringList *
cloog_next_scattering (CloogScatteringList *sl)
{
  return sl->next;
}

static inline void
cloog_set_next_scattering (CloogScatteringList *sl, CloogScatteringList *next)
{
  sl->next = next;
}

static inline int
cloog_program_nb_scattdims (CloogProgram *prog)
{
  return prog->nb_scattdims;
}

static inline void
cloog_program_set_nb_scattdims (CloogProgram *prog, int nb_scattdims)
{
  prog->nb_scattdims = nb_scattdims;
}

static inline CloogNames *
cloog_program_names (CloogProgram *prog)
{
  return prog->names;
}

static inline void
cloog_program_set_names (CloogProgram *prog, CloogNames *names)
{
  prog->names = names;
}

static inline void
cloog_program_set_context (CloogProgram *prog, CloogDomain *domain)
{
  prog->context = domain;
}

static inline void
cloog_program_set_loop (CloogProgram *prog, CloogLoop *loop)
{
  prog->loop = loop;
}

static inline CloogBlockList *
cloog_program_blocklist (CloogProgram *prog)
{
  return prog->blocklist;
}

static inline void
cloog_program_set_blocklist (CloogProgram *prog, CloogBlockList *bl)
{
  prog->blocklist = bl;
}

static inline int *
cloog_program_scaldims (CloogProgram *prog)
{
  return prog->scaldims;
}

static inline void
cloog_program_set_scaldims (CloogProgram *prog, int *s)
{
  prog->scaldims = s;
}

static inline int
cloog_names_nb_parameters (CloogNames *names)
{
  return names->nb_parameters;
}

static inline void
cloog_names_set_nb_parameters (CloogNames *names, int nb_parameters)
{
  names->nb_parameters = nb_parameters;
}

static inline char **
cloog_names_parameters (CloogNames *names)
{
  return names->parameters;
}

static inline void
cloog_names_set_parameters (CloogNames *names, char **parameters)
{
  names->parameters = parameters;
}

static inline void
cloog_names_set_nb_iterators (CloogNames *names, int nb_iterators)
{
  names->nb_iterators = nb_iterators;
}

static inline void
cloog_names_set_iterators (CloogNames *names, char **iterators)
{
  names->iterators = iterators;
}

static inline void
cloog_names_set_nb_scattering (CloogNames *names, int nb_scattering)
{
  names->nb_scattering = nb_scattering;
}

static inline void
cloog_names_set_scattering (CloogNames *names, char **scattering)
{
  names->scattering = scattering;
}

static inline void
cloog_statement_set_usr (CloogStatement *cs, void *u)
{
  cs->usr = u;
}

static inline void
cloog_loop_set_next (CloogLoop *loop, CloogLoop *next)
{
  loop->next = next;
}

static inline void
cloog_loop_set_domain (CloogLoop *loop, CloogDomain *domain)
{
  loop->domain = domain;
}

static inline void
cloog_loop_set_block (CloogLoop *loop, CloogBlock *block)
{
  loop->block = block;
}

static inline CloogBlockList *
cloog_block_list_next (CloogBlockList *bl)
{
  return bl->next;
}

static inline void
cloog_block_list_set_next (CloogBlockList *bl, CloogBlockList *next)
{
  bl->next = next;
}

static inline void
cloog_block_list_set_block (CloogBlockList *bl, CloogBlock *block)
{
  bl->block = block;
}

static inline int cloog_matrix_ncolumns (CloogMatrix * m)
{
  return m->NbColumns;
}

static inline int cloog_matrix_nrows (CloogMatrix * m)
{
   return m->NbRows;
}
#endif /* CLOOG_ORG  */

#include <dlfcn.h>
#if PPL_VERSION_MAJOR == 0 && PPL_VERSION_MINOR < 11
#define DYNSYMS_PPL11
#else
#define DYNSYMS_PPL11 \
  DYNSYM (ppl_new_PIP_Problem_from_constraints); \
  DYNSYM (ppl_PIP_Problem_is_satisfiable); \
  DYNSYM (ppl_delete_PIP_Problem);
#endif
#define DYNSYMS \
  DYNSYM (cloog_block_alloc); \
  DYNSYM (cloog_block_list_free); \
  DYNSYM (cloog_block_list_malloc); \
  DYNSYM (cloog_clast_create); \
  DYNSYM (cloog_clast_free); \
  DYNSYM (cloog_domain_free); \
  DYNSYM (cloog_domain_matrix2domain); \
  DYNSYM (cloog_initialize); \
  DYNSYM (cloog_loop_malloc); \
  DYNSYM (cloog_matrix_alloc); \
  DYNSYM (cloog_matrix_copy); \
  DYNSYM (cloog_matrix_free); \
  DYNSYM (cloog_matrix_print); \
  DYNSYM (cloog_names_malloc); \
  DYNSYM (cloog_names_scalarize); \
  DYNSYM (cloog_options_free); \
  DYNSYM (cloog_options_malloc); \
  DYNSYM (cloog_program_dump_cloog); \
  DYNSYM (cloog_program_extract_scalars); \
  DYNSYM (cloog_program_free); \
  DYNSYM (cloog_program_generate); \
  DYNSYM (cloog_program_malloc); \
  DYNSYM (cloog_program_print); \
  DYNSYM (cloog_program_scatter); \
  DYNSYM (cloog_statement_alloc); \
  DYNSYM (cloog_domain_union); \
  DYNSYM (cloog_matrix_read); \
  DYNSYM (cloog_new_pol); \
  DYNSYM (cloog_vector_gcd); \
  DYNSYM (ppl_finalize); \
  DYNSYM (ppl_assign_Coefficient_from_mpz_t); \
  DYNSYM (ppl_assign_Linear_Expression_from_Linear_Expression); \
  DYNSYM (ppl_Coefficient_to_mpz_t); \
  DYNSYM (ppl_Constraint_coefficient); \
  DYNSYM (ppl_Constraint_inhomogeneous_term); \
  DYNSYM (ppl_Constraint_space_dimension); \
  DYNSYM (ppl_Constraint_System_begin); \
  DYNSYM (ppl_Constraint_System_const_iterator_dereference); \
  DYNSYM (ppl_Constraint_System_const_iterator_equal_test); \
  DYNSYM (ppl_Constraint_System_const_iterator_increment); \
  DYNSYM (ppl_Constraint_System_end); \
  DYNSYM (ppl_Constraint_System_insert_Constraint); \
  DYNSYM (ppl_Constraint_System_space_dimension); \
  DYNSYM (ppl_Constraint_type); \
  DYNSYM (ppl_delete_Coefficient); \
  DYNSYM (ppl_delete_Constraint); \
  DYNSYM (ppl_delete_Constraint_System_const_iterator); \
  DYNSYM (ppl_delete_Linear_Expression); \
  DYNSYM (ppl_delete_Pointset_Powerset_C_Polyhedron); \
  DYNSYM (ppl_delete_Pointset_Powerset_C_Polyhedron_iterator); \
  DYNSYM (ppl_delete_Polyhedron); \
  DYNSYM (ppl_Linear_Expression_add_to_coefficient); \
  DYNSYM (ppl_Linear_Expression_add_to_inhomogeneous); \
  DYNSYM (ppl_Linear_Expression_coefficient); \
  DYNSYM (ppl_Linear_Expression_inhomogeneous_term); \
  DYNSYM (ppl_Linear_Expression_space_dimension); \
  DYNSYM (ppl_new_Coefficient); \
  DYNSYM (ppl_new_Coefficient_from_mpz_t); \
  DYNSYM (ppl_new_Constraint); \
  DYNSYM (ppl_new_Constraint_System); \
  DYNSYM (ppl_new_Constraint_System_const_iterator); \
  DYNSYM (ppl_new_C_Polyhedron_from_C_Polyhedron); \
  DYNSYM (ppl_new_C_Polyhedron_from_space_dimension); \
  DYNSYM (ppl_new_C_Polyhedron_recycle_Constraint_System); \
  DYNSYM (ppl_new_Linear_Expression); \
  DYNSYM (ppl_new_Linear_Expression_from_Constraint); \
  DYNSYM (ppl_new_Linear_Expression_from_Linear_Expression); \
  DYNSYM (ppl_new_Linear_Expression_with_dimension); \
  DYNSYM (ppl_new_Pointset_Powerset_C_Polyhedron_from_C_Polyhedron); \
  DYNSYM (ppl_new_Pointset_Powerset_C_Polyhedron_from_Pointset_Powerset_C_Polyhedron); \
  DYNSYM (ppl_new_Pointset_Powerset_C_Polyhedron_from_space_dimension); \
  DYNSYM (ppl_new_Pointset_Powerset_C_Polyhedron_iterator); \
  DYNSYM (ppl_Pointset_Powerset_C_Polyhedron_add_constraint); \
  DYNSYM (ppl_Pointset_Powerset_C_Polyhedron_add_space_dimensions_and_embed); \
  DYNSYM (ppl_Pointset_Powerset_C_Polyhedron_difference_assign); \
  DYNSYM (ppl_Pointset_Powerset_C_Polyhedron_intersection_assign); \
  DYNSYM (ppl_Pointset_Powerset_C_Polyhedron_is_empty); \
  DYNSYM (ppl_Pointset_Powerset_C_Polyhedron_iterator_begin); \
  DYNSYM (ppl_Pointset_Powerset_C_Polyhedron_iterator_dereference); \
  DYNSYM (ppl_Pointset_Powerset_C_Polyhedron_iterator_end); \
  DYNSYM (ppl_Pointset_Powerset_C_Polyhedron_iterator_equal_test); \
  DYNSYM (ppl_Pointset_Powerset_C_Polyhedron_iterator_increment); \
  DYNSYM (ppl_Pointset_Powerset_C_Polyhedron_map_space_dimensions); \
  DYNSYM (ppl_Pointset_Powerset_C_Polyhedron_maximize); \
  DYNSYM (ppl_Pointset_Powerset_C_Polyhedron_minimize); \
  DYNSYM (ppl_Pointset_Powerset_C_Polyhedron_remove_space_dimensions); \
  DYNSYM (ppl_Pointset_Powerset_C_Polyhedron_size); \
  DYNSYM (ppl_Pointset_Powerset_C_Polyhedron_space_dimension); \
  DYNSYM (ppl_Pointset_Powerset_C_Polyhedron_upper_bound_assign); \
  DYNSYM (ppl_Polyhedron_add_constraint); \
  DYNSYM (ppl_Polyhedron_add_constraints); \
  DYNSYM (ppl_Polyhedron_add_space_dimensions_and_embed); \
  DYNSYM (ppl_Polyhedron_get_constraints); \
  DYNSYM (ppl_Polyhedron_map_space_dimensions); \
  DYNSYM (ppl_Polyhedron_remove_space_dimensions); \
  DYNSYM (ppl_Polyhedron_space_dimension); \
  DYNSYM (ppl_subtract_Linear_Expression_from_Linear_Expression); \
  DYNSYM (pprint); \
  DYNSYM (stmt_block); \
  DYNSYM (stmt_for); \
  DYNSYM (stmt_guard); \
  DYNSYM (stmt_root); \
  DYNSYM (stmt_user); \
  DYNSYM (stmt_ass); \
  DYNSYM (ppl_delete_Constraint_System); \
  DYNSYM (ppl_initialize); \
  DYNSYM (ppl_new_Constraint_System_from_Constraint); \
  DYNSYM (ppl_new_C_Polyhedron_from_Constraint_System); \
  DYNSYM (ppl_Polyhedron_affine_image); \
  DYNSYM (ppl_io_fprint_Pointset_Powerset_C_Polyhedron); \
  DYNSYMS_PPL11
extern struct cloog_pointers_s__
{
  bool inited;
  void *h;
#define DYNSYM(x) __typeof (x) *p_##x
  DYNSYMS
#undef DYNSYM
} cloog_pointers__;

#define cloog_block_alloc (*cloog_pointers__.p_cloog_block_alloc)
#define cloog_block_list_free (*cloog_pointers__.p_cloog_block_list_free)
#define cloog_block_list_malloc (*cloog_pointers__.p_cloog_block_list_malloc)
#define cloog_clast_create (*cloog_pointers__.p_cloog_clast_create)
#define cloog_clast_free (*cloog_pointers__.p_cloog_clast_free)
#define cloog_domain_free (*cloog_pointers__.p_cloog_domain_free)
#define cloog_domain_matrix2domain (*cloog_pointers__.p_cloog_domain_matrix2domain)
#define cloog_initialize (*cloog_pointers__.p_cloog_initialize)
#ifndef CLOOG_ORG
#undef cloog_loop_malloc
#define cloog_loop_malloc(STATE) (*cloog_pointers__.p_cloog_loop_malloc) ()
#else
#define cloog_loop_malloc (*cloog_pointers__.p_cloog_loop_malloc)
#endif
#define cloog_matrix_alloc (*cloog_pointers__.p_cloog_matrix_alloc)
#define cloog_matrix_copy (*cloog_pointers__.p_cloog_matrix_copy)
#define cloog_matrix_free (*cloog_pointers__.p_cloog_matrix_free)
#define cloog_matrix_print (*cloog_pointers__.p_cloog_matrix_print)
#define cloog_names_malloc (*cloog_pointers__.p_cloog_names_malloc)
#define cloog_names_scalarize (*cloog_pointers__.p_cloog_names_scalarize)
#define cloog_options_free (*cloog_pointers__.p_cloog_options_free)
#ifndef CLOOG_ORG
#undef cloog_options_malloc
#define cloog_options_malloc(STATE) (*cloog_pointers__.p_cloog_options_malloc) ()
#undef cloog_program_dump_cloog
#define cloog_program_dump_cloog(DUMPFILE, PROGRAM, SCATTERINGLIST) \
  (*cloog_pointers__.p_cloog_program_dump_cloog) (DUMPFILE, PROGRAM)
#undef cloog_program_extract_scalars
#define cloog_program_extract_scalars(PROG, SCATT, OPT) \
  (*cloog_pointers__.p_cloog_program_extract_scalars) (PROG, SCATT)
#else
#define cloog_options_malloc (*cloog_pointers__.p_cloog_options_malloc)
#define cloog_program_dump_cloog (*cloog_pointers__.p_cloog_program_dump_cloog)
#define cloog_program_extract_scalars (*cloog_pointers__.p_cloog_program_extract_scalars)
#endif
#define cloog_program_free (*cloog_pointers__.p_cloog_program_free)
#define cloog_program_generate (*cloog_pointers__.p_cloog_program_generate)
#define cloog_program_malloc (*cloog_pointers__.p_cloog_program_malloc)
#define cloog_program_print (*cloog_pointers__.p_cloog_program_print)
#ifndef CLOOG_ORG
#undef cloog_program_scatter
#define cloog_program_scatter(PROG, SCATT, OPT) \
  (*cloog_pointers__.p_cloog_program_scatter) (PROG, SCATT)
#undef cloog_statement_alloc
#define cloog_statement_alloc(STATE, INDEX) \
  (*cloog_pointers__.p_cloog_statement_alloc) (INDEX)
#else
#define cloog_program_scatter (*cloog_pointers__.p_cloog_program_scatter)
#define cloog_statement_alloc (*cloog_pointers__.p_cloog_statement_alloc)
#endif
#define cloog_domain_union (*cloog_pointers__.p_cloog_domain_union)
#define cloog_matrix_read (*cloog_pointers__.p_cloog_matrix_read)
#define cloog_new_pol (*cloog_pointers__.p_cloog_new_pol)
#define cloog_vector_gcd (*cloog_pointers__.p_cloog_vector_gcd)
#define ppl_finalize (*cloog_pointers__.p_ppl_finalize)
#define ppl_assign_Coefficient_from_mpz_t (*cloog_pointers__.p_ppl_assign_Coefficient_from_mpz_t)
#define ppl_assign_Linear_Expression_from_Linear_Expression (*cloog_pointers__.p_ppl_assign_Linear_Expression_from_Linear_Expression)
#define ppl_Coefficient_to_mpz_t (*cloog_pointers__.p_ppl_Coefficient_to_mpz_t)
#define ppl_Constraint_coefficient (*cloog_pointers__.p_ppl_Constraint_coefficient)
#define ppl_Constraint_inhomogeneous_term (*cloog_pointers__.p_ppl_Constraint_inhomogeneous_term)
#define ppl_Constraint_space_dimension (*cloog_pointers__.p_ppl_Constraint_space_dimension)
#define ppl_Constraint_System_begin (*cloog_pointers__.p_ppl_Constraint_System_begin)
#define ppl_Constraint_System_const_iterator_dereference (*cloog_pointers__.p_ppl_Constraint_System_const_iterator_dereference)
#define ppl_Constraint_System_const_iterator_equal_test (*cloog_pointers__.p_ppl_Constraint_System_const_iterator_equal_test)
#define ppl_Constraint_System_const_iterator_increment (*cloog_pointers__.p_ppl_Constraint_System_const_iterator_increment)
#define ppl_Constraint_System_end (*cloog_pointers__.p_ppl_Constraint_System_end)
#define ppl_Constraint_System_insert_Constraint (*cloog_pointers__.p_ppl_Constraint_System_insert_Constraint)
#define ppl_Constraint_System_space_dimension (*cloog_pointers__.p_ppl_Constraint_System_space_dimension)
#define ppl_Constraint_type (*cloog_pointers__.p_ppl_Constraint_type)
#define ppl_delete_Coefficient (*cloog_pointers__.p_ppl_delete_Coefficient)
#define ppl_delete_Constraint (*cloog_pointers__.p_ppl_delete_Constraint)
#define ppl_delete_Constraint_System_const_iterator (*cloog_pointers__.p_ppl_delete_Constraint_System_const_iterator)
#define ppl_delete_Linear_Expression (*cloog_pointers__.p_ppl_delete_Linear_Expression)
#define ppl_delete_Pointset_Powerset_C_Polyhedron (*cloog_pointers__.p_ppl_delete_Pointset_Powerset_C_Polyhedron)
#define ppl_delete_Pointset_Powerset_C_Polyhedron_iterator (*cloog_pointers__.p_ppl_delete_Pointset_Powerset_C_Polyhedron_iterator)
#define ppl_delete_Polyhedron (*cloog_pointers__.p_ppl_delete_Polyhedron)
#define ppl_Linear_Expression_add_to_coefficient (*cloog_pointers__.p_ppl_Linear_Expression_add_to_coefficient)
#define ppl_Linear_Expression_add_to_inhomogeneous (*cloog_pointers__.p_ppl_Linear_Expression_add_to_inhomogeneous)
#define ppl_Linear_Expression_coefficient (*cloog_pointers__.p_ppl_Linear_Expression_coefficient)
#define ppl_Linear_Expression_inhomogeneous_term (*cloog_pointers__.p_ppl_Linear_Expression_inhomogeneous_term)
#define ppl_Linear_Expression_space_dimension (*cloog_pointers__.p_ppl_Linear_Expression_space_dimension)
#define ppl_new_Coefficient (*cloog_pointers__.p_ppl_new_Coefficient)
#define ppl_new_Coefficient_from_mpz_t (*cloog_pointers__.p_ppl_new_Coefficient_from_mpz_t)
#define ppl_new_Constraint (*cloog_pointers__.p_ppl_new_Constraint)
#define ppl_new_Constraint_System (*cloog_pointers__.p_ppl_new_Constraint_System)
#define ppl_new_Constraint_System_const_iterator (*cloog_pointers__.p_ppl_new_Constraint_System_const_iterator)
#define ppl_new_C_Polyhedron_from_C_Polyhedron (*cloog_pointers__.p_ppl_new_C_Polyhedron_from_C_Polyhedron)
#define ppl_new_C_Polyhedron_from_space_dimension (*cloog_pointers__.p_ppl_new_C_Polyhedron_from_space_dimension)
#define ppl_new_C_Polyhedron_recycle_Constraint_System (*cloog_pointers__.p_ppl_new_C_Polyhedron_recycle_Constraint_System)
#define ppl_new_Linear_Expression (*cloog_pointers__.p_ppl_new_Linear_Expression)
#define ppl_new_Linear_Expression_from_Constraint (*cloog_pointers__.p_ppl_new_Linear_Expression_from_Constraint)
#define ppl_new_Linear_Expression_from_Linear_Expression (*cloog_pointers__.p_ppl_new_Linear_Expression_from_Linear_Expression)
#define ppl_new_Linear_Expression_with_dimension (*cloog_pointers__.p_ppl_new_Linear_Expression_with_dimension)
#define ppl_new_Pointset_Powerset_C_Polyhedron_from_C_Polyhedron (*cloog_pointers__.p_ppl_new_Pointset_Powerset_C_Polyhedron_from_C_Polyhedron)
#define ppl_new_Pointset_Powerset_C_Polyhedron_from_Pointset_Powerset_C_Polyhedron (*cloog_pointers__.p_ppl_new_Pointset_Powerset_C_Polyhedron_from_Pointset_Powerset_C_Polyhedron)
#define ppl_new_Pointset_Powerset_C_Polyhedron_from_space_dimension (*cloog_pointers__.p_ppl_new_Pointset_Powerset_C_Polyhedron_from_space_dimension)
#define ppl_new_Pointset_Powerset_C_Polyhedron_iterator (*cloog_pointers__.p_ppl_new_Pointset_Powerset_C_Polyhedron_iterator)
#define ppl_Pointset_Powerset_C_Polyhedron_add_constraint (*cloog_pointers__.p_ppl_Pointset_Powerset_C_Polyhedron_add_constraint)
#define ppl_Pointset_Powerset_C_Polyhedron_add_space_dimensions_and_embed (*cloog_pointers__.p_ppl_Pointset_Powerset_C_Polyhedron_add_space_dimensions_and_embed)
#define ppl_Pointset_Powerset_C_Polyhedron_difference_assign (*cloog_pointers__.p_ppl_Pointset_Powerset_C_Polyhedron_difference_assign)
#define ppl_Pointset_Powerset_C_Polyhedron_intersection_assign (*cloog_pointers__.p_ppl_Pointset_Powerset_C_Polyhedron_intersection_assign)
#define ppl_Pointset_Powerset_C_Polyhedron_is_empty (*cloog_pointers__.p_ppl_Pointset_Powerset_C_Polyhedron_is_empty)
#define ppl_Pointset_Powerset_C_Polyhedron_iterator_begin (*cloog_pointers__.p_ppl_Pointset_Powerset_C_Polyhedron_iterator_begin)
#define ppl_Pointset_Powerset_C_Polyhedron_iterator_dereference (*cloog_pointers__.p_ppl_Pointset_Powerset_C_Polyhedron_iterator_dereference)
#define ppl_Pointset_Powerset_C_Polyhedron_iterator_end (*cloog_pointers__.p_ppl_Pointset_Powerset_C_Polyhedron_iterator_end)
#define ppl_Pointset_Powerset_C_Polyhedron_iterator_equal_test (*cloog_pointers__.p_ppl_Pointset_Powerset_C_Polyhedron_iterator_equal_test)
#define ppl_Pointset_Powerset_C_Polyhedron_iterator_increment (*cloog_pointers__.p_ppl_Pointset_Powerset_C_Polyhedron_iterator_increment)
#define ppl_Pointset_Powerset_C_Polyhedron_map_space_dimensions (*cloog_pointers__.p_ppl_Pointset_Powerset_C_Polyhedron_map_space_dimensions)
#define ppl_Pointset_Powerset_C_Polyhedron_maximize (*cloog_pointers__.p_ppl_Pointset_Powerset_C_Polyhedron_maximize)
#define ppl_Pointset_Powerset_C_Polyhedron_minimize (*cloog_pointers__.p_ppl_Pointset_Powerset_C_Polyhedron_minimize)
#define ppl_Pointset_Powerset_C_Polyhedron_remove_space_dimensions (*cloog_pointers__.p_ppl_Pointset_Powerset_C_Polyhedron_remove_space_dimensions)
#define ppl_Pointset_Powerset_C_Polyhedron_size (*cloog_pointers__.p_ppl_Pointset_Powerset_C_Polyhedron_size)
#define ppl_Pointset_Powerset_C_Polyhedron_space_dimension (*cloog_pointers__.p_ppl_Pointset_Powerset_C_Polyhedron_space_dimension)
#define ppl_Pointset_Powerset_C_Polyhedron_upper_bound_assign (*cloog_pointers__.p_ppl_Pointset_Powerset_C_Polyhedron_upper_bound_assign)
#define ppl_Polyhedron_add_constraint (*cloog_pointers__.p_ppl_Polyhedron_add_constraint)
#define ppl_Polyhedron_add_constraints (*cloog_pointers__.p_ppl_Polyhedron_add_constraints)
#define ppl_Polyhedron_add_space_dimensions_and_embed (*cloog_pointers__.p_ppl_Polyhedron_add_space_dimensions_and_embed)
#define ppl_Polyhedron_get_constraints (*cloog_pointers__.p_ppl_Polyhedron_get_constraints)
#define ppl_Polyhedron_map_space_dimensions (*cloog_pointers__.p_ppl_Polyhedron_map_space_dimensions)
#define ppl_Polyhedron_remove_space_dimensions (*cloog_pointers__.p_ppl_Polyhedron_remove_space_dimensions)
#define ppl_Polyhedron_space_dimension (*cloog_pointers__.p_ppl_Polyhedron_space_dimension)
#define ppl_subtract_Linear_Expression_from_Linear_Expression (*cloog_pointers__.p_ppl_subtract_Linear_Expression_from_Linear_Expression)
#define pprint (*cloog_pointers__.p_pprint)
#define stmt_block (*cloog_pointers__.p_stmt_block)
#define stmt_for (*cloog_pointers__.p_stmt_for)
#define stmt_guard (*cloog_pointers__.p_stmt_guard)
#define stmt_root (*cloog_pointers__.p_stmt_root)
#define stmt_user (*cloog_pointers__.p_stmt_user)
#define stmt_ass (*cloog_pointers__.p_stmt_ass)
#define ppl_delete_Constraint_System (*cloog_pointers__.p_ppl_delete_Constraint_System)
#define ppl_initialize (*cloog_pointers__.p_ppl_initialize)
#define ppl_new_Constraint_System_from_Constraint (*cloog_pointers__.p_ppl_new_Constraint_System_from_Constraint)
#define ppl_new_C_Polyhedron_from_Constraint_System (*cloog_pointers__.p_ppl_new_C_Polyhedron_from_Constraint_System)
#define ppl_Polyhedron_affine_image (*cloog_pointers__.p_ppl_Polyhedron_affine_image)
#define ppl_io_fprint_Pointset_Powerset_C_Polyhedron (*cloog_pointers__.p_ppl_io_fprint_Pointset_Powerset_C_Polyhedron)
#if !(PPL_VERSION_MAJOR == 0 && PPL_VERSION_MINOR < 11)
#define ppl_new_PIP_Problem_from_constraints (*cloog_pointers__.p_ppl_new_PIP_Problem_from_constraints)
#define ppl_PIP_Problem_is_satisfiable (*cloog_pointers__.p_ppl_PIP_Problem_is_satisfiable)
#define ppl_delete_PIP_Problem (*cloog_pointers__.p_ppl_delete_PIP_Problem)
#endif

#define cloog_finalize (*cloog_pointers__.p_ppl_finalize)


#endif /* GRAPHITE_CLOOG_COMPAT_H  */
